/* $Id: cpumask.h,v 1.1 2003/08/17 22:15:58 mikpe Exp $
 * Performance-monitoring counters driver.
 * Partial simulation of cpumask_t on non-cpumask_t kernels.
 * Extension to allow inspecting a cpumask_t as array of ulong.
 * Appropriate definition of perfctr_cpus_forbidden_mask.
 *
 * Copyright (C) 2003  Mikael Pettersson
 */

#include <linux/sched.h>	/* brings in cpumask_t #defines, if present */

#if !defined(CPU_MASK_NONE)

typedef unsigned long cpumask_t;

#define cpu_set(cpu, map)	atomic_set_mask((1UL << (cpu)), &(map))
#define cpu_isset(cpu, map)	((map) & (1UL << (cpu)))
#define cpus_and(dst,src1,src2)	do { (dst) = (src1) & (src2); } while(0)
#define cpus_clear(map)		do { (map) = 0UL; } while(0)
#define cpus_complement(map)	do { (map) = ~(map); } while(0)
#define cpus_empty(map)		((map) == 0UL)
#define cpus_equal(map1, map2)	((map1) == (map2))

#define CPU_MASK_NONE		0UL

#endif	/* !defined(CPU_MASK_NONE) */

#ifdef CPU_ARRAY_SIZE
#define PERFCTR_CPUMASK_NRLONGS	CPU_ARRAY_SIZE
#define perfctr_cpus_mask(cpus)	((cpus).mask)
#else
#define PERFCTR_CPUMASK_NRLONGS	1
#define perfctr_cpus_mask(cpus)	(&(cpus))
#endif

/* `perfctr_cpus_forbidden_mask' used to be defined in <asm/perfctr.h>,
   but cpumask_t compatibility issues forced it to be moved here. */
#if PERFCTR_CPUS_FORBIDDEN_MASK_NEEDED
extern cpumask_t perfctr_cpus_forbidden_mask;
#else
#define perfctr_cpus_forbidden_mask	CPU_MASK_NONE
#endif
